from distutils.core import setup

setup(
  name = "myNesterPyPI",
  version = "1.0.3",
  py_modules = ['myNesterPyPI'],
  author = "Alex",
  author_email = "123@123.com",
  description = "A simple printer of nested lists, add default value for second parameter"
)
